# Offer API

### Import a file to add offers [OF01](https://help.mirakl.net/help/api-doc/operator/mmp.html#OF01) - [OperatorClient]

```javascript
const res = await client.importOffers({
  file: "file-stream",
  import_mode: "string", // "NORMAL", "PARTIAL_UPDATE", "REPLACE"
  shop: "number",
  with_products: "boolean",
});
```

#### Response

```javascript
{
  data: {
    import_id: "integer",
    product_import_id: "integer"
  }
}
```

### Get information and statistics about an offer import [OF02](https://help.mirakl.net/help/api-doc/operator/mmp.html#OF02) - [OperatorClient]

```javascript
const res = await client.getStatusForOffersImportByImportId(12345);
```

#### Response

```javascript
{
  data: {
    date_created: "string",
    has_error_report: "boolean",
    import_id: "integer",
    lines_in_error: "integer",
    lines_in_pending: "integer",
    lines_in_success: "integer",
    lines_read: "integer",
    mode: "string",
    offer_deleted: "integer",
    offer_inserted: "integer",
    offer_updated: "integer",
    reason_status: "string",
    status: "string",
    type: "string",
  },
};
```

### Get the error report file for an offer import [OF03](https://help.mirakl.net/help/api-doc/operator/mmp.html#OF03) - [OperatorClient]

```javascript
const res = await client.getErrorReportForOfferImportByImportId(12345);
```

#### Response

```javascript
{
  data: "file";
}
```

### List offer conditions [OF61](https://help.mirakl.net/help/api-doc/operator/mmp.html#OF61) - [OperatorClient]

```javascript
const res = await client.getListOfferConditions({
  active: "boolean",
  locale: "string",
});
```

#### Response

```javascript
{
  data: {
    offer_states: [
      {
        active: "boolean",
        code: "string",
        label: "string",
      },
    ],
    total_count: "integer",
  },
}
```

### Get information about an offer [OF22](https://help.mirakl.net/help/api-doc/operator/mmp.html#OF22) - [OperatorClient]

```javascript
const res = await client.getOfferByOfferId({
  offerId: "number",
  pricing_channel_code: "string",
  locale: "string",
});
```

#### Response

```javascript
{
  data: {
    active: "boolean",
    all_prices: [
      {
        channel_code: "string",
        discount_end_date: "string",
        discount_start_date: "string",
        price: "number",
        unit_discount_price: "number",
        unit_origin_price: "number",
        volume_prices: [
          {
            price: "number",
            quantity_threshold: "integer",
            unit_discount_price: "number",
            unit_origin_price: "number",
          },
        ],
      },
    ],
    allow_quote_requests: "boolean",
    applicable_pricing: {
      channel_code: "string",
      discount_end_date: "string",
      discount_start_date: "string",
      price: "number",
      unit_discount_price: "number",
      unit_origin_price: "number",
      volume_prices: [
        {
          price: "number",
          quantity_threshold: "integer",
          unit_discount_price: "number",
          unit_origin_price: "number",
        },
      ],
    },
    available_end_date: "string",
    available_start_date: "string",
    category_code: "string",
    category_label: "string",
    channels: ["string"],
    currency_iso_code: "string",
    description: "string",
    discount: {
      discount_price: "number",
      end_date: "string",
      origin_price: "number",
      ranges: [
        {
          price: "number",
          quantity_threshold: "integer",
        },
      ],
      start_date: "string",
    },
    favorite_rank: "integer",
    inactivity_reasons: ["string"],
    leadtime_to_ship: "integer",
    logistic_class: {
      code: "string",
      label: "string",
    },
    max_order_quantity: "integer",
    min_order_quantity: "integer",
    min_quantity_alert: "integer",
    min_shipping_price: "number",
    min_shipping_price_additional: "number",
    min_shipping_type: "string",
    min_shipping_zone: "string",
    offer_additional_fields: [
      {
        code: "string",
        type: "string",
        value: "string",
      },
    ],
    offer_id: "integer",
    package_quantity: "integer",
    price: "number",
    price_additional_info: "string",
    product_references: [
      {
        reference: "string",
        reference_type: "string",
      },
    ],
    product_sku: "string",
    product_tax_code: "string",
    product_title: "string",
    quantity: "integer",
    shop_grade: "number",
    shop_id: "integer",
    shop_name: "string",
    state_code: "string",
    total_price: "number",
  },
}
```

### Get offers CSV file [OF51](https://help.mirakl.net/help/api-doc/operator/mmp.html#OF51) - [OperatorClient]

```javascript
const res = await client.exportOffers({
  last_request_date: "string", // 2021-02-25T01:04:51+00:00
  channel_codes: "string",
  include_inactive_offers: "boolean",
});
```

#### Response

```javascript
{
  data: "file";
}
```
