# Order API

### Download one or multiple documents attached to one or multiple orders [OR73](https://help.mirakl.net/help/api-doc/operator/mmp.html#OR73) - [OperatorClient, FrontClient]

```javascript
const res = await client.downloadDocumentsByOrderIds({
    orderIds: ["string"],
    documentIds: ["string"],
    documentCodes: ["string"],
});
```

#### Response

```javascript
{
    data: "file";
}
```

### Lists order's documents [OR72](https://help.mirakl.net/help/api-doc/operator/mmp.html#OR72) - [OperatorClient, FrontClient]

```javascript
const res = await client.getListOrderDocumentsByOrderIds(["string"]);
```

#### Response

```javascript
{
    data: {
        order_documents: [
            {
                date_uploaded: "string",
                file_name: "string",
                file_size: "integer",
                id: "integer",
                order_id: "string",
                type: "string",
            },
        ],
            total_count
    :
        "integer",
    }
,
}
```

### Close an incident on an order line [OR63](https://help.mirakl.net/help/api-doc/operator/mmp.html#OR63) - [OperatorClient, FrontClient]

```javascript
const res = await client.closeIncidentByOrderLine({
    id: "string",
    line: "string",
    data: {
        reason_code: "string",
    },
});
```

#### Response 204 no content

```javascript
{
    data: "";
}
```

### Post an incident on an order line [OR62](https://help.mirakl.net/help/api-doc/operator/mmp.html#OR62) - [OperatorClient, FrontClient]

```javascript
const res = await client.openIncidentByOrderLine({
    id: "string",
    line: "string",
    data: {
        reason_code: "string",
    },
});
```

#### Response 201 created

```javascript
{
    data: "";
}
```

### Get the evaluation of an order [OR51](https://help.mirakl.net/help/api-doc/operator/mmp.html#OR51) - [OperatorClient, FrontClient]

```javascript
const res = await client.getEvaluationByOrderId({
    orderId: "string",
    locale: "string",
});
```

#### Response

```javascript
{
    data: {
        assessments: [
            {
                code: "string",
                label: "string",
                response: "string",
            },
        ],
            comment
    :
        "string",
            customer_id
    :
        "string",
            date
    :
        "string",
            firstname
    :
        "string",
            grade
    :
        "integer",
            last_updated_date
    :
        "string",
            lastname
    :
        "string",
            reply
    :
        {
            comment: "string",
                date
        :
            "string",
                type
        :
            "string",
        }
    ,
        visible: "boolean",
    }
,
}
;
```

### Validate the receipt of an order [OR25](https://help.mirakl.net/help/api-doc/operator/mmp.html#OR25) - [OperatorClient, FrontClient]

```javascript
const res = await client.validateReceiptByOrderId("order-id");
```

#### Response 204 no content

```javascript
{
    data: "";
}
```

### Upload documents to attach to an order [POST OR74](https://help.mirakl.net/help/api-doc/operator/mmp.html#OR74) - [OperatorClient, FrontClient]

```javascript
const res = await client.uploadDocumentsByOrderId({
    orderId: "string",
    data: {
        files: ["file-stream"],
        order_documents: [
            {
                file_name: "string",
                type_code: "string",
            },
        ],
    },
});
```

#### Response

```javascript
{
    data: {
        errors_count: "integer",
            order_documents
    :
        [
            {
                errors: [
                    {
                        code: "string",
                        field: "string",
                        message: "string",
                    },
                ],
            },
        ],
    }
,
}
;
```

### Accept or refuse order lines [PUT OR21](https://help.mirakl.net/help/api-doc/operator/mmp.html#OR21) - [OperatorClient, FrontClient]

```javascript
const res = await client.acceptOrRefuseOrderLines({
    orderId: "string",
    data: {
        order_lines: [
            {
                accepted: "boolean",
                id: "string",
            },
        ],
    },
});
```

#### Response

```javascript
{
    data: {
        order_lines: [
            {
                accepted: "boolean",
                id: "string",
            },
        ],
    }
,
}
;
```

### List orders [GET OR11](https://help.mirakl.net/help/api-doc/front/mmp.html#OR11) - [OperatorClient, FrontClient]

```javascript
const res = await client.getListOrders({
    commercial_ids: ["string"],
    customer_ids: ["string"],
    offer_ids: ["string"],
    order_ids: ["string"],
    shop_ids: ["string"],
    product_skus: ["string"],
    order_state_codes: ["string"],
    channel_codes: ["string"],
    only_null_channel: "boolean",
    start_date: "string", // 2021-02-25T01:04:51+00:00
    end_date: "string", // 2021-02-25T01:04:51+00:00
    start_update_date: "string", // 2021-02-25T01:04:51+00:00
    end_update_date: "string", // 2021-02-25T01:04:51+00:00
    paginate: "boolean",
    customer_debited: "boolean",
    payment_workflow: "string", // "PAY_ON_ACCEPTANCE", "PAY_ON_DELIVERY", "PAY_ON_DUE_DATE"
    has_incident: "boolean",
    fulfillment_center_code: ["string"],
    order_tax_mode: "string", // "TAX_EXCLUDED", "TAX_INCLUDED"
    locale: "string",
    max: "number",
    offset: "number",
    sort: "string",
    order: "string",
});
```

#### Response

```javascript
{
    data: {
        orders: [
            {
                acceptance_decision_date: "string",
                can_cancel: "boolean",
                can_evaluate: "boolean",
                can_shop_ship: "boolean",
                channel: {
                    code: "string",
                    label: "string",
                },
                commercial_id: "string",
                created_date: "string",
                currency_iso_code: "string",
                customer: {
                    billing_address: {
                        city: "string",
                        civility: "string",
                        company: "string",
                        country: "string",
                        country_iso_code: "string",
                        firstname: "string",
                        lastname: "string",
                        phone: "string",
                        phone_secondary: "string",
                        state: "string",
                        street_1: "string",
                        street_2: "string",
                        zip_code: "string",
                    },
                    civility: "string",
                    customer_id: "string",
                    email: "string",
                    firstname: "string",
                    lastname: "string",
                    locale: "string",
                    shipping_address: {
                        additional_info: "string",
                        city: "string",
                        civility: "string",
                        company: "string",
                        country: "string",
                        country_iso_code: "string",
                        firstname: "string",
                        internal_additional_info: "string",
                        lastname: "string",
                        phone: "string",
                        phone_secondary: "string",
                        state: "string",
                        street_1: "string",
                        street_2: "string",
                        zip_code: "string",
                    },
                },
                customer_debited_date: "string",
                delivery_date: {
                    earliest: "string",
                    latest: "string",
                },
                fulfillment: {
                    center: {
                        code: "string",
                    },
                },
                has_customer_message: "boolean",
                has_incident: "boolean",
                has_invoice: "boolean",
                imprint_number: "string",
                last_updated_date: "string",
                leadtime_to_ship: "integer",
                order_additional_fields: [
                    {
                        code: "string",
                        type: "string",
                        value: "string",
                    },
                ],
                order_id: "string",
                order_lines: [
                    {
                        can_open_incident: "boolean",
                        can_refund: "boolean",
                        cancelations: [
                            {
                                amount: "number",
                                amount_breakdown: {
                                    parts: [
                                        {
                                            amount: "number",
                                            commissionable: "boolean",
                                            debitable_from_customer: "boolean",
                                            payable_to_shop: "boolean",
                                        },
                                    ],
                                },
                                commission_amount: "number",
                                commission_taxes: [
                                    {
                                        amount: "number",
                                        code: "string",
                                    },
                                ],
                                commission_total_amount: "number",
                                created_date: "string",
                                id: "string",
                                quantity: "integer",
                                reason_code: "string",
                                shipping_amount: "number",
                                shipping_amount_breakdown: {
                                    parts: [
                                        {
                                            amount: "number",
                                            commissionable: "boolean",
                                            debitable_from_customer: "boolean",
                                            payable_to_shop: "boolean",
                                        },
                                    ],
                                },
                                shipping_taxes: [
                                    {
                                        amount: "number",
                                        amount_breakdown: {
                                            parts: [
                                                {
                                                    amount: "number",
                                                    commissionable: "boolean",
                                                    debitable_from_customer: "boolean",
                                                    payable_to_shop: "boolean",
                                                },
                                            ],
                                        },
                                        code: "string",
                                        rate: "number",
                                    },
                                ],
                                taxes: [
                                    {
                                        amount: "number",
                                        amount_breakdown: {
                                            parts: [
                                                {
                                                    amount: "number",
                                                    commissionable: "boolean",
                                                    debitable_from_customer: "boolean",
                                                    payable_to_shop: "boolean",
                                                },
                                            ],
                                        },
                                        code: "string",
                                        rate: "number",
                                    },
                                ],
                            },
                        ],
                        category_code: "string",
                        category_label: "string",
                        commission_fee: "number",
                        commission_rate_vat: "number",
                        commission_taxes: [
                            {
                                amount: "number",
                                code: "string",
                                rate: "number",
                            },
                        ],
                        commission_vat: "number",
                        created_date: "string",
                        debited_date: "string",
                        description: "string",
                        last_updated_date: "string",
                        measurement: {
                            actual_measurement: "number",
                            adjustment_limit: "number",
                            measurement_unit: "string",
                            ordered_measurement: "number",
                        },
                        offer_id: "integer",
                        offer_sku: "string",
                        offer_state_code: "string",
                        order_line_additional_fields: [
                            {
                                code: "string",
                                type: "string",
                                value: "string",
                            },
                        ],
                        order_line_id: "string",
                        order_line_index: "integer",
                        order_line_state: "string",
                        order_line_state_reason_code: "string",
                        order_line_state_reason_label: "string",
                        price: "number",
                        price_additional_info: "string",
                        price_amount_breakdown: {
                            parts: [
                                {
                                    amount: "number",
                                    commissionable: "boolean",
                                    debitable_from_customer: "boolean",
                                    payable_to_shop: "boolean",
                                },
                            ],
                        },
                        price_unit: "number",
                        product_medias: [
                            {
                                media_url: "string",
                                mime_type: "string",
                                type: "string",
                            },
                        ],
                        product_sku: "string",
                        product_title: "string",
                        promotions: [
                            {
                                apportioned: "boolean",
                                configuration: {
                                    amount_off: "number",
                                    free_items_quantity: "integer",
                                    internal_description: "string",
                                    percentage_off: "number",
                                    type: "string",
                                },
                                deduced_amount: "number",
                                id: "string",
                                offered_quantity: "integer",
                            },
                        ],
                        quantity: "integer",
                        received_date: "string",
                        refunds: [
                            {
                                amount: "number",
                                amount_breakdown: {
                                    parts: [
                                        {
                                            amount: "number",
                                            commissionable: "boolean",
                                            debitable_from_customer: "boolean",
                                            payable_to_shop: "boolean",
                                        },
                                    ],
                                },
                                commission_amount: "number",
                                commission_tax_amount: "number",
                                commission_taxes: [
                                    {
                                        amount: "number",
                                        code: "string",
                                    },
                                ],
                                commission_total_amount: "number",
                                created_date: "string",
                                id: "string",
                                quantity: "integer",
                                reason_code: "string",
                                shipping_amount: "number",
                                shipping_amount_breakdown: {
                                    parts: [
                                        {
                                            amount: "number",
                                            commissionable: "boolean",
                                            debitable_from_customer: "boolean",
                                            payable_to_shop: "boolean",
                                        },
                                    ],
                                },
                                shipping_taxes: [
                                    {
                                        amount: "number",
                                        amount_breakdown: {
                                            parts: [
                                                {
                                                    amount: "number",
                                                    commissionable: "boolean",
                                                    debitable_from_customer: "boolean",
                                                    payable_to_shop: "boolean",
                                                },
                                            ],
                                        },
                                        code: "string",
                                        rate: "number",
                                    },
                                ],
                                state: "string",
                                taxes: [
                                    {
                                        amount: "number",
                                        amount_breakdown: {
                                            parts: [
                                                {
                                                    amount: "number",
                                                    commissionable: "boolean",
                                                    debitable_from_customer: "boolean",
                                                    payable_to_shop: "boolean",
                                                },
                                            ],
                                        },
                                        code: "string",
                                        rate: "number",
                                    },
                                ],
                                transaction_date: "string",
                                transaction_number: "string",
                            },
                        ],
                        shipped_date: "string",
                        shipping_price: "number",
                        shipping_price_additional_unit: "number",
                        shipping_price_amount_breakdown: {
                            parts: [
                                {
                                    amount: "number",
                                    commissionable: "boolean",
                                    debitable_from_customer: "boolean",
                                    payable_to_shop: "boolean",
                                },
                            ],
                        },
                        shipping_price_unit: "number",
                        shipping_taxes: [
                            {
                                amount: "number",
                                amount_breakdown: {
                                    parts: [
                                        {
                                            amount: "number",
                                            commissionable: "boolean",
                                            debitable_from_customer: "boolean",
                                            payable_to_shop: "boolean",
                                        },
                                    ],
                                },
                                code: "string",
                                rate: "number",
                                tax_calculation_rule: "string",
                            },
                        ],
                        taxes: [
                            {
                                amount: "number",
                                amount_breakdown: {
                                    parts: [
                                        {
                                            amount: "number",
                                            commissionable: "boolean",
                                            debitable_from_customer: "boolean",
                                            payable_to_shop: "boolean",
                                        },
                                    ],
                                },
                                code: "string",
                                rate: "number",
                                tax_calculation_rule: "string",
                            },
                        ],
                        total_commission: "number",
                        total_price: "number",
                    },
                ],
                order_state: "string",
                order_state_reason_code: "string",
                order_state_reason_label: "string",
                order_tax_mode: "string",
                paymentType: "string",
                payment_duration: "integer",
                payment_type: "string",
                payment_workflow: "string",
                price: "number",
                promotions: {
                    applied_promotions: [
                        {
                            apportioned: "boolean",
                            configuration: {
                                amount_off: "number",
                                free_items_quantity: "integer",
                                internal_description: "string",
                                percentage_off: "number",
                                type: "string",
                            },
                            deduced_amount: "number",
                            id: "string",
                            offered_quantity: "integer",
                        },
                    ],
                    total_deduced_amount: "number",
                },
                quote_id: "string",
                shipping_carrier_code: "string",
                shipping_company: "string",
                shipping_deadline: "string",
                shipping_price: "number",
                shipping_pudo_id: "string",
                shipping_tracking: "string",
                shipping_tracking_url: "string",
                shipping_type_code: "string",
                shipping_type_label: "string",
                shipping_zone_code: "string",
                shipping_zone_label: "string",
                shop_id: "integer",
                shop_name: "string",
                total_commission: "number",
                total_price: "number",
                transaction_date: "string",
                transaction_number: "string",
            },
        ],
            total_count
    :
        "integer",
    }
,
}
;
```

### Update carrier tracking information for a specific order [OR23](https://help.mirakl.net/help/api-doc/front/mmp.html#OR23) - [OperatorClient, FrontClient]

```javascript
const res = await client.updateTrackingInfoByOrderId({
    orderId: "string",
    data: {
        carrier_code: "string",
        carrier_name: "string",
        carrier_url: "string",
        tracking_number: "string",
    },
});
```

#### Response 204 no content

```javascript
{
    data: "";
}
```

### Validate the shipment of an order [OR24](https://help.mirakl.net/help/api-doc/operator/mmp.html#OR24) - [OperatorClient, FrontClient]

```javascript
const res = await client.validateShipmentByOrderId("order-id");
```

#### Response 204 no content

```javascript
{
    data: "";
}
```

### Create an order [OR01](https://help.mirakl.net/help/api-doc/front/mmp.html#OR01) - [FrontClient]

```javascript
const res = await client.createOrders({
    channel_code: "string",
    commercial_id: "string",
    customer: {
        billing_address: {
            city: "string",
            civility: "string",
            company: "string",
            country: "string",
            country_iso_code: "string",
            firstname: "string",
            lastname: "string",
            phone: "string",
            phone_secondary: "string",
            state: "string",
            street_1: "string",
            street_2: "string",
            zip_code: "string",
        },
        civility: "string",
        customer_id: "string",
        email: "string",
        firstname: "string",
        lastname: "string",
        locale: "string",
        shipping_address: {
            additional_info: "string",
            city: "string",
            civility: "string",
            company: "string",
            country: "string",
            country_iso_code: "string",
            firstname: "string",
            internal_additional_info: "string",
            lastname: "string",
            phone: "string",
            phone_secondary: "string",
            state: "string",
            street_1: "string",
            street_2: "string",
            zip_code: "string",
        },
    },
    offers: Joi.array().items({
        adjustment_limit: "number",
        currency_iso_code: "string",
        delivery_date: {
            earliest: "string", // // 2021-02-25T01:04:51+00:00
            latest: "string", // // 2021-02-25T01:04:51+00:00
        },
        leadtime_to_ship: "number",
        offer_id: "number",
        offer_price: "number",
        order_line_additional_fields: Joi.array()
            .items({
                code: "string",
                value: "string",
            })
            .optional()
            .default([]),
        order_line_id: "string",
        price: "number",
        quantity: Joi.number().positive().required(),
        shipping_deadline: Joi.date().iso().required(),
        shipping_price: "number",
        shipping_pudo_id: Joi.string().allow(null).optional(),
        shipping_taxes: Joi.array()
            .items({
                amount: "number",
                code: "string",
                rate: "number",
            })
            .optional()
            .default([]),
        shipping_type_code: "string",
        taxes: Joi.array()
            .items({
                amount: "number",
                code: "string",
                rate: "number",
            })
            .optional()
            .default([]),
    }),
    order_additional_fields: Joi.array()
        .items({
            code: "string",
            value: "string",
        })
        .optional()
        .default([]),
    order_tax_mode: "string",
    payment_duration: "number",
    payment_info: Joi.object()
        .keys({
            imprint_number: "string",
            payment_type: "string",
        })
        .required(),
    payment_workflow: "string",
    scored: Joi.boolean().required(),
    shipping_zone_code: "string",
});
```

#### Response

```javascript
{
    data: {
        "offers_not_shippable"
    :
        [
            {
                "error_code": "string",
                "offer_id": "integer"
            }
        ],
            "orders"
    :
        [
            {
                "acceptance_decision_date": "string",
                "can_cancel": "boolean",
                "can_evaluate": "boolean",
                "can_shop_ship": "boolean",
                "channel": {
                    "code": "string",
                    "label": "string"
                },
                "commercial_id": "string",
                "created_date": "string",
                "currency_iso_code": "string",
                "customer": {
                    "billing_address": {
                        "city": "string",
                        "civility": "string",
                        "company": "string",
                        "country": "string",
                        "country_iso_code": "string",
                        "firstname": "string",
                        "lastname": "string",
                        "phone": "string",
                        "phone_secondary": "string",
                        "state": "string",
                        "street_1": "string",
                        "street_2": "string",
                        "zip_code": "string"
                    },
                    "civility": "string",
                    "customer_id": "string",
                    "email": "string",
                    "firstname": "string",
                    "lastname": "string",
                    "locale": "string",
                    "shipping_address": {
                        "additional_info": "string",
                        "city": "string",
                        "civility": "string",
                        "company": "string",
                        "country": "string",
                        "country_iso_code": "string",
                        "firstname": "string",
                        "internal_additional_info": "string",
                        "lastname": "string",
                        "phone": "string",
                        "phone_secondary": "string",
                        "state": "string",
                        "street_1": "string",
                        "street_2": "string",
                        "zip_code": "string"
                    }
                },
                "customer_debited_date": "string",
                "delivery_date": {
                    "earliest": "string",
                    "latest": "string"
                },
                "fulfillment": {
                    "center": {
                        "code": "string"
                    }
                },
                "has_customer_message": "boolean",
                "has_incident": "boolean",
                "has_invoice": "boolean",
                "imprint_number": "string",
                "last_updated_date": "string",
                "leadtime_to_ship": "integer",
                "order_additional_fields": [
                    {
                        "code": "string",
                        "type": "string",
                        "value": "string"
                    }
                ],
                "order_id": "string",
                "order_lines": [
                    {
                        "can_open_incident": "boolean",
                        "can_refund": "boolean",
                        "cancelations": [
                            {
                                "amount": "number",
                                "amount_breakdown": {
                                    "parts": [
                                        {
                                            "amount": "number",
                                            "commissionable": "boolean",
                                            "debitable_from_customer": "boolean",
                                            "payable_to_shop": "boolean"
                                        }
                                    ]
                                },
                                "commission_amount": "number",
                                "commission_taxes": [
                                    {
                                        "amount": "number",
                                        "code": "string"
                                    }
                                ],
                                "commission_total_amount": "number",
                                "created_date": "string",
                                "id": "string",
                                "quantity": "integer",
                                "reason_code": "string",
                                "shipping_amount": "number",
                                "shipping_amount_breakdown": {
                                    "parts": [
                                        {
                                            "amount": "number",
                                            "commissionable": "boolean",
                                            "debitable_from_customer": "boolean",
                                            "payable_to_shop": "boolean"
                                        }
                                    ]
                                },
                                "shipping_taxes": [
                                    {
                                        "amount": "number",
                                        "amount_breakdown": {
                                            "parts": [
                                                {
                                                    "amount": "number",
                                                    "commissionable": "boolean",
                                                    "debitable_from_customer": "boolean",
                                                    "payable_to_shop": "boolean"
                                                }
                                            ]
                                        },
                                        "code": "string",
                                        "rate": "number"
                                    }
                                ],
                                "taxes": [
                                    {
                                        "amount": "number",
                                        "amount_breakdown": {
                                            "parts": [
                                                {
                                                    "amount": "number",
                                                    "commissionable": "boolean",
                                                    "debitable_from_customer": "boolean",
                                                    "payable_to_shop": "boolean"
                                                }
                                            ]
                                        },
                                        "code": "string",
                                        "rate": "number"
                                    }
                                ]
                            }
                        ],
                        "category_code": "string",
                        "category_label": "string",
                        "commission_fee": "number",
                        "commission_rate_vat": "number",
                        "commission_taxes": [
                            {
                                "amount": "number",
                                "code": "string",
                                "rate": "number"
                            }
                        ],
                        "commission_vat": "number",
                        "created_date": "string",
                        "debited_date": "string",
                        "description": "string",
                        "last_updated_date": "string",
                        "measurement": {
                            "actual_measurement": "number",
                            "adjustment_limit": "number",
                            "measurement_unit": "string",
                            "ordered_measurement": "number"
                        },
                        "offer_id": "integer",
                        "offer_sku": "string",
                        "offer_state_code": "string",
                        "order_line_additional_fields": [
                            {
                                "code": "string",
                                "type": "string",
                                "value": "string"
                            }
                        ],
                        "order_line_id": "string",
                        "order_line_index": "integer",
                        "order_line_state": "string",
                        "order_line_state_reason_code": "string",
                        "order_line_state_reason_label": "string",
                        "price": "number",
                        "price_additional_info": "string",
                        "price_amount_breakdown": {
                            "parts": [
                                {
                                    "amount": "number",
                                    "commissionable": "boolean",
                                    "debitable_from_customer": "boolean",
                                    "payable_to_shop": "boolean"
                                }
                            ]
                        },
                        "price_unit": "number",
                        "product_medias": [
                            {
                                "media_url": "string",
                                "mime_type": "string",
                                "type": "string"
                            }
                        ],
                        "product_sku": "string",
                        "product_title": "string",
                        "promotions": [
                            {
                                "apportioned": "boolean",
                                "configuration": {
                                    "amount_off": "number",
                                    "free_items_quantity": "integer",
                                    "internal_description": "string",
                                    "percentage_off": "number",
                                    "type": "string"
                                },
                                "deduced_amount": "number",
                                "id": "string",
                                "offered_quantity": "integer"
                            }
                        ],
                        "quantity": "integer",
                        "received_date": "string",
                        "refunds": [
                            {
                                "amount": "number",
                                "amount_breakdown": {
                                    "parts": [
                                        {
                                            "amount": "number",
                                            "commissionable": "boolean",
                                            "debitable_from_customer": "boolean",
                                            "payable_to_shop": "boolean"
                                        }
                                    ]
                                },
                                "commission_amount": "number",
                                "commission_tax_amount": "number",
                                "commission_taxes": [
                                    {
                                        "amount": "number",
                                        "code": "string"
                                    }
                                ],
                                "commission_total_amount": "number",
                                "created_date": "string",
                                "id": "string",
                                "quantity": "integer",
                                "reason_code": "string",
                                "shipping_amount": "number",
                                "shipping_amount_breakdown": {
                                    "parts": [
                                        {
                                            "amount": "number",
                                            "commissionable": "boolean",
                                            "debitable_from_customer": "boolean",
                                            "payable_to_shop": "boolean"
                                        }
                                    ]
                                },
                                "shipping_taxes": [
                                    {
                                        "amount": "number",
                                        "amount_breakdown": {
                                            "parts": [
                                                {
                                                    "amount": "number",
                                                    "commissionable": "boolean",
                                                    "debitable_from_customer": "boolean",
                                                    "payable_to_shop": "boolean"
                                                }
                                            ]
                                        },
                                        "code": "string",
                                        "rate": "number"
                                    }
                                ],
                                "state": "string",
                                "taxes": [
                                    {
                                        "amount": "number",
                                        "amount_breakdown": {
                                            "parts": [
                                                {
                                                    "amount": "number",
                                                    "commissionable": "boolean",
                                                    "debitable_from_customer": "boolean",
                                                    "payable_to_shop": "boolean"
                                                }
                                            ]
                                        },
                                        "code": "string",
                                        "rate": "number"
                                    }
                                ],
                                "transaction_date": "string",
                                "transaction_number": "string"
                            }
                        ],
                        "shipped_date": "string",
                        "shipping_price": "number",
                        "shipping_price_additional_unit": "number",
                        "shipping_price_amount_breakdown": {
                            "parts": [
                                {
                                    "amount": "number",
                                    "commissionable": "boolean",
                                    "debitable_from_customer": "boolean",
                                    "payable_to_shop": "boolean"
                                }
                            ]
                        },
                        "shipping_price_unit": "number",
                        "shipping_taxes": [
                            {
                                "amount": "number",
                                "amount_breakdown": {
                                    "parts": [
                                        {
                                            "amount": "number",
                                            "commissionable": "boolean",
                                            "debitable_from_customer": "boolean",
                                            "payable_to_shop": "boolean"
                                        }
                                    ]
                                },
                                "code": "string",
                                "rate": "number",
                                "tax_calculation_rule": "string"
                            }
                        ],
                        "taxes": [
                            {
                                "amount": "number",
                                "amount_breakdown": {
                                    "parts": [
                                        {
                                            "amount": "number",
                                            "commissionable": "boolean",
                                            "debitable_from_customer": "boolean",
                                            "payable_to_shop": "boolean"
                                        }
                                    ]
                                },
                                "code": "string",
                                "rate": "number",
                                "tax_calculation_rule": "string"
                            }
                        ],
                        "total_commission": "number",
                        "total_price": "number"
                    }
                ],
                "order_state": "string",
                "order_state_reason_code": "string",
                "order_state_reason_label": "string",
                "order_tax_mode": "string",
                "paymentType": "string",
                "payment_duration": "integer",
                "payment_type": "string",
                "payment_workflow": "string",
                "price": "number",
                "promotions": {
                    "applied_promotions": [
                        {
                            "apportioned": "boolean",
                            "configuration": {
                                "amount_off": "number",
                                "free_items_quantity": "integer",
                                "internal_description": "string",
                                "percentage_off": "number",
                                "type": "string"
                            },
                            "deduced_amount": "number",
                            "id": "string",
                            "offered_quantity": "integer"
                        }
                    ],
                    "total_deduced_amount": "number"
                },
                "quote_id": "string",
                "shipping_carrier_code": "string",
                "shipping_company": "string",
                "shipping_deadline": "string",
                "shipping_price": "number",
                "shipping_pudo_id": "string",
                "shipping_tracking": "string",
                "shipping_tracking_url": "string",
                "shipping_type_code": "string",
                "shipping_type_label": "string",
                "shipping_zone_code": "string",
                "shipping_zone_label": "string",
                "shop_id": "integer",
                "shop_name": "string",
                "total_commission": "number",
                "total_price": "number",
                "transaction_date": "string",
                "transaction_number": "string"
            }
        ]
    }
}
```

###    
