# Product API

### Export products [CM51](https://help.mirakl.net/help/api-doc/front/mcm.html#CM51) - [OperatorClient, FrontClient]

```javascript
const res = await client.exportProducts({
  updated_since: "string", // 2021-02-25T01:04:51+00:00
  updated_to: "string", // 2021-02-25T01:04:51+00:00
  acceptance_status: ["string"], // "NEW","REJECTED","ACCEPTED","CHANGES_REQUESTED","TO_REVIEW"
  validation_status: ["string"], // "VALID", "INVALID"
  synchronization_status: ["string"], // "SYNCHRONIZED", "PENDING", "INTEGRATION_ERRORS"
  product_sku: ["string"], // max 100
  product_id: ["string"], // max 100
  variant_group_code: ["string"], // max 100
  catalog: ["string"], // max 100
  rejection_reason: ["string"], // max 100
  category: ["string"], // max 100
});
```

#### Response

```javascript
{
  data: {
    acceptance: {
      message: "string",
      reason_code: "string",
      status: "string",
    },
    catalogs: ["string"],
    creation_date: "string",
    data: "object",
    mirakl_product_id: "string",
    product_sku: "string",
    product_urls: [
      {
        link: "string",
        qualifier: "string",
      },
    ],
    selling_authorization: {
      authorized_selling_shop_ids: ["string"],
      restricted: "boolean",
    },
    sources: [
      {
        provider_id: "string",
        provider_unique_identifier: "string",
      },
    ],
    synchronization: {
      integration_errors: [
        {
          attribute_code: "string",
          code: "string",
          message: "string",
        },
      ],
      status: "string",
    },
    update_date: "string",
    validation: {
      product_feeds: [
        {
          code: "string",
          status: "string",
        },
      ],
      status: "string",
    },
  },
};
```

### Import products to the operator information system [P41](https://help.mirakl.net/help/api-doc/front/mcm.html#P41) - [OperatorClient, FrontClient]

```javascript
const res = await client.importProduct({
  file: "file-stream",
  shop: "number",
});
```

#### Response

```javascript
{
  data: {
    import_id: "integer",
  },
};
```

### Get the import status for a product import [P42](https://help.mirakl.net/help/api-doc/front/mcm.html#P42) - [OperatorClient, FrontClient]

```javascript
const res = await client.getStatusForProductImportByImportId(12345);
```

#### Response

```javascript
{
  data: {
    date_created: "string",
    has_error_report: "boolean",
    has_new_product_report: "boolean",
    has_transformation_error_report: "boolean",
    has_transformed_file: "boolean",
    import_id: "integer",
    import_status: "string",
    integration_details: {
      invalid_products: "integer",
      products_not_accepted_in_time: "integer",
      products_not_synchronized_in_time: "integer",
      products_reimported: "integer",
      products_successfully_synchronized: "integer",
      products_with_synchronization_issues: "integer",
      products_with_wrong_identifiers: "integer",
      rejected_products: "integer",
    },
    reason_status: "string",
    shop_id: "integer",
    transform_lines_in_error: "integer",
    transform_lines_in_success: "integer",
    transform_lines_read: "integer",
    transform_lines_with_warning: "integer",
  },
};
```
