const Joi = require('joi');
const client = require('../core/client');
const { validationError, failure } = require('../core/result');

const SHIPMENTS = '/api/shipments';

const listShipmentsSchema = Joi.object().keys({
    order_id: Joi.string().optional(),
    shipment_state_code: Joi.string().optional(),
}).required();

/**
 * List shipments [GET ST11]{@link https://help.mirakl.net/help/api-doc/front/mmp.html#ST11}
 * This method returns the shipments of each order.
 * @param {Object} request
 * @param {string} request.url
 * @param {Object} request.headers
 * @param {Object} request.params
 * @param {string} request.params.order_id
 * @param {string} request.params.shipping_state_code
 */
const getListShipments = ({ url, headers, params }) => {
  const { error, value } = listShipmentsSchema.validate(params);
  if (error) {
    return validationError(error.details);
  }
  const newParams = {
    ...value
  };
  return client
    .getRequest({
      url: url + SHIPMENTS,
      headers,
      params: newParams,
    })
    .then((res) => {
      return res;
    });
};

module.exports = (ctx) => {
  if (ctx) {
    const { name } = ctx;
    if (name === 'FrontClient' || name === 'OperatorClient') {
      ctx.prototype.getListShipments = function (params) {
        return getListShipments({ ...this._config, params });
      };
    }
  }
};
