const axios = require('axios');

const { success, failure } = require('./result');

const defaultHeaders = {
  'Content-Type': 'application/json',
  Accept: 'application/json',
};

const METHODS = {
  GET: 'GET',
  POST: 'POST',
  PUT: 'PUT',
  DELETE: 'DELETE',
};

const fetch = async ({
  url, method, params, data, headers
}) => {
  if (!url) {
    return failure('url cannot be null');
  }
  if (!method || !METHODS[method]) {
    return failure('invalid method');
  }
  try {
    console.log('request details', JSON.stringify({
      url,
      method,
      params,
      data,
    }));
    const result = await axios({
      url,
      method,
      params,
      data,
      headers: !headers
        ? defaultHeaders
        : ({ ...defaultHeaders, ...headers }),
    });
    return success(result.data);
  } catch (error) {
    if (error.response) {
      const { status, message } = error.response.data;
      try {
        console.error('response error from Mirakl', JSON.stringify({ status, message }));
      } catch (e) {
        console.error('json parsing error ', e.message);
      }
      return failure(
        message || error.message,
        error.response.data,
        status || error.response.status
      );
    }
    console.error('axios error', error.message);
    return failure(error.message);
  }
};

const getRequest = ({ url, params, headers }) => {
  return fetch({
    url, method: METHODS.GET, params, headers
  });
};

const deleteRequest = ({ url, params, headers }) => {
  return fetch({
    url, method: METHODS.DELETE, params, headers
  });
};

const postRequest = ({
  url, params, data, headers
}) => {
  return fetch({
    url, method: METHODS.POST, data, params, headers
  });
};

const putRequest = ({
  url, params, data, headers
}) => {
  return fetch({
    url, method: METHODS.PUT, data, params, headers
  });
};

module.exports = {
  getRequest,
  deleteRequest,
  postRequest,
  putRequest,
};
